<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.9 (2016/10/21)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_doc_helper.php';

class Add_menuitems_helper extends Add_doc_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_writer_rights = array(); // Droits du rédacteur
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($writer_rights = array())
    {
        parent :: __construct(TYP_OPTMENU, $writer_rights);    

        /**
         * Récupération de nouveaux paramètres
         */
        if (empty($this -> _form_params['menuid'])) { // Id du menu contenant les items
            $this -> _form_params['menuid'] = Var_helper :: import('menuid', 'GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));           
        }
        
        // Id du document interne liés aux items
        $this -> _form_params['docid'] = Var_helper :: import('itemdocid', 'GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));
       
        if (!empty($this -> _form_params['docid']) && empty($_POST) && empty($this -> _form_params['id'])) {
            $this -> _form_params = array_merge(
                $this -> _form_params,
                $this -> _get_internal_doc_data($this -> _form_params['docid'], $unset = array('id', 'type'))
            );
        }
        //
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        return parent :: set_menu_plugin_items();         
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/public_add_record.js"></script>'."\n";
        
        $css = '';
//        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/public_add_record.css" />'."\n";

        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
	 * Récupère les données du document interne de l'item de menu
     * 
	 * @access private
     * @param integer Id du document interne
     * @param mixed Données du document interne à supprimer (vide par défaut)
     * @return array Tableau contenant les données du document interne
	 */	
    private function _get_internal_doc_data($doc_id, $unset = array())
    {
        $doc_params = array();
        $doc = $this -> CI -> writer_docs_model -> get_by_id($doc_id);

        if (!empty($doc)) {
            $doc_infos = Model :: get_doc_infos_by_type($doc['type']);
            
            $this -> CI -> load_model($doc_infos['name'].'_model');
            $doc_params = $this -> CI -> {$doc_infos['name'].'_model'} -> read($doc['id']);
            
            // Supression des paramètres indésirables si nécessaire
            if (!empty($unset)) {
                settype($unset, 'array');
                
                foreach($unset as $field) {
                    if (!empty($doc_params[$field])) {
                        unset($doc_params[$field]);
                    }
                }
            }
        }

        //
        
        return $doc_params;
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {        
        return array_merge(
            parent :: _add_more_data_for_add_record_view(), 
            array(
                'boxmenus' => $this -> _get_menu_boxes(), // Boites de menus
                'docs' => $this -> _get_internal_docs(),  // Documents internes
                'templates' => $this -> _get_page_templates(), // Gabarits de la page déclarés dans la skin choisie
                'url_external_allowed' => TRUE, // Autorisation d'insérer des url externes
                'sidebars_display_mode_allowed' => TRUE // Autorisation ou non de choisir le mode d'affichage des barres latérales                
            )
        );
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des boites de menus
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_menu_boxes()
    {        
        $boxmenus = array();
        $doc_infos = $this -> _doc_infos;
        $autorization = $this -> _writer_rights[$doc_infos['name'].'_boxes_manage'];

        if (! empty($autorization)) {
            $this -> CI -> load_helper('boxmenus_helper');

            if ($autorization == '1') { // Toutes les boites menus enregistrées dans guppy (par défaut)           
                $boxmenus = $this -> CI -> boxmenus_helper -> get_all(); //  
            }
            //
            elseif ($autorization == '2') { // Uniquement les boites menus sélectionnées
                $boxes_ids = $this -> _writer_rights[$doc_infos['name'].'_boxes_list_allowed'];
                $boxmenus = $this -> CI -> boxmenus_helper -> get_by_id($boxes_ids);    
            }
            //
            elseif ($autorization == '3') { // Uniquement les boites menus du rédacteur           
                $boxes_ids = array_keys($this -> CI -> writer_docs_model -> get(array('type' => TYP_MENUBOX)));
                $boxmenus = $this -> CI -> boxmenus_helper -> get_by_id($boxes_ids);    
            }
            //
           
        }

        return $boxmenus;     
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des gabarits de la page déclarées dans la skin choisie
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => array('id' => , 'name' =>))
	 */
    protected function _get_page_templates()
    {
        $this -> CI -> load_helper('templates_helper');
        
        $templates = $this -> CI -> templates_helper -> get_all_layouts(); // Tous les gabarits enregistrés dana la skin choisie

        if ($this -> _writer_rights['menuitems_templates_manage'] == 2) {
            $templates = array_intersect_key($templates, array_flip($this -> _writer_rights['menuitems_templates_list_allowed']));    
        }      
                 
        return $templates;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur
	 *
	 * @access	protected
	 * @return	array sous la forme array(path => array())
	 */
    protected function _get_internal_docs()
    {
        $docs = array();
        $doc_paths = $this -> CI -> menuitems_model -> get_internal_doc_paths();
        
        foreach($doc_paths as $doc_infos => $doc_path) {
            $docs += array($doc_path => $this -> _get_writer_docs($doc_infos));
        }
        
        return $docs;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur
	 *
	 * @access	private
	 * @return	array sous la forme array(id => name)
	 */
    private function _get_writer_docs($doc_infos)
    {
        $docs = array();
        $docs += $this -> _get_writer_docs_indexed($doc_infos); // Documents indexés dans fichier index/TYPE_DOC.dtb       
        $docs += $this -> _get_writer_docs_not_indexed($doc_infos); // Documents avec status i
        
        ksort($docs);
 
        return $docs;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur enregistrés dans le fichier index (document activés uniquement)
	 *
	 * @access	private
	 * @return	array sous la forme array(id => array())
	 */
    private function _get_writer_docs_indexed($doc_infos)
    {        
        $docs = array();
        $doc_infos = $this -> CI -> writer_docs_model -> get_doc_types($doc_infos);
        $autorization = $this -> _writer_rights[$doc_infos['name'].'_manage'];
      
        if (! empty($autorization)) {
            $this -> CI -> load_model($doc_infos['name'].'_index_model');
            $guppy_index_docs = $this -> CI -> {$doc_infos['name'].'_index_model'} -> read(); // Tous les documents enregistrées dans le fichier index de guppy                     
            $writer_docs = $this -> CI -> writer_docs_model -> get_many_by_type($doc_infos['type']); // Tous les documents enregistrées dans guppy
        
            $docs = array_intersect_key($guppy_index_docs, $writer_docs);
        }

        return $docs;     
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur non enregistrés dans le fichier index (document inactivés uniquement)
	 *
	 * @access	private
	 * @return	array sous la forme array(id => array())
	 */
    private function _get_writer_docs_not_indexed($doc_infos)
    {        
        $docs = array();
        $doc_infos = $this -> CI -> writer_docs_model -> get_doc_types($doc_infos);
        $autorization = $this -> _writer_rights[$doc_infos['name'].'_manage'];
       
        if (! empty($autorization)) {
            $this -> CI -> load_model($doc_infos['name'].'_model');
            
            $writer_docs_inactivated = $this -> CI -> writer_docs_model -> get(array('status' => 'i', 'type' => $doc_infos['type'])); // Tous les documents inactifs enregistrés dans guppy

            foreach($writer_docs_inactivated as $id => $doc) {
                $docs[$id] = $this -> CI -> {$doc_infos['name'].'_model'} -> read($id);    
            }
        }

        return $docs;     
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit les valeurs des paramètres du formulaire
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array
	 */    
/*    protected function _set_form_params($record_id)
    {    
        return parent :: _set_form_params($record_id);       
    }
*/
	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
/*    protected function _get_form_params_posted()
    {
        return parent :: _get_form_params_posted();       
    }
*/
	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
/*    protected function _get_form_params_rules($params)
    {
        return parent :: _get_form_params_rules($params);
    }
*/
	// --------------------------------------------------------------------

	/**
	 * retourne l'url complète de la page
     * 
     * @access protected
	 * @return string Url complète de la page
	 */
/*    protected function _get_current_url()
    {
        return parent :: _get_current_url();
    }
*/
	// --------------------------------------------------------------------
    
} // End of class